==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/outputs/ListNetworkManagerEffectiveSecurityAdminRulesResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.outputs

import com.pulumi.core.Either
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Result of the request to list networkManagerEffectiveSecurityAdminRules. It contains a list of groups and a skiptoken to get the next set of results.
 * @property skipToken When present, the value can be passed to a subsequent query call (together with the same query and scopes used in the current request) to retrieve the next page of data.
 * @property value Gets a page of NetworkManagerEffectiveSecurityAdminRules
 */
public data class ListNetworkManagerEffectiveSecurityAdminRulesResult(
    public val skipToken: String? = null,
    public val `value`:
    List<Either<EffectiveDefaultSecurityAdminRuleResponse, EffectiveSecurityAdminRuleResponse>>? =
        null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.network.outputs.ListNetworkManagerEffectiveSecurityAdminRulesResult):
            ListNetworkManagerEffectiveSecurityAdminRulesResult =
            ListNetworkManagerEffectiveSecurityAdminRulesResult(
                skipToken = javaType.skipToken().map({ args0 -> args0 }).orElse(null),
                `value` = javaType.`value`().map({ args0 ->
                    args0.transform(
                        { args0 ->
                            args0.let({ args0 ->
                                com.pulumi.azurenative.network.kotlin.outputs.EffectiveDefaultSecurityAdminRuleResponse.Companion.toKotlin(args0)
                            })
                        },
                        { args0 ->
                            args0.let({ args0 ->
                                com.pulumi.azurenative.network.kotlin.outputs.EffectiveSecurityAdminRuleResponse.Companion.toKotlin(args0)
                            })
                        },
                    )
                }),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/network/kotlin/outputs/ListNetworkManagerEffectiveSecurityAdminRulesResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.outputs

import com.pulumi.core.Either
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Result of the request to list networkManagerEffectiveSecurityAdminRules. It contains a list of groups and a skiptoken to get the next set of results.
 * @property skipToken When present, the value can be passed to a subsequent query call (together with the same query and scopes used in the current request) to retrieve the next page of data.
 * @property value Gets a page of NetworkManagerEffectiveSecurityAdminRules
 */
public data class ListNetworkManagerEffectiveSecurityAdminRulesResult(
    public val skipToken: String? = null,
    public val `value`: List<Either<EffectiveDefaultSecurityAdminRuleResponse, EffectiveSecurityAdminRuleResponse>>? =
        null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.network.outputs.ListNetworkManagerEffectiveSecurityAdminRulesResult): ListNetworkManagerEffectiveSecurityAdminRulesResult =
            ListNetworkManagerEffectiveSecurityAdminRulesResult(
                skipToken = javaType.skipToken().map({ args0 -> args0 }).orElse(null),
                `value` = javaType.`value`().map({ args0 ->
                    args0.transform(
                        { args0 ->
                            args0.let({ args0 ->
                                com.pulumi.azurenative.network.kotlin.outputs.EffectiveDefaultSecurityAdminRuleResponse.Companion.toKotlin(args0)
                            })
                        },
                        { args0 ->
                            args0.let({ args0 ->
                                com.pulumi.azurenative.network.kotlin.outputs.EffectiveSecurityAdminRuleResponse.Companion.toKotlin(args0)
                            })
                        },
                    )
                }),
            )
    }
}
